@@ -7,7 +7,7 @@ Helper code for connecting to AzureML and sharing one workspace accross code.
 
 
 import argparse
-from azureml.core import Workspace
+from azureml.core import Workspace, Run
 from collections import namedtuple
 import logging
 import os
@@ -78,7 +78,7 @@ def add_cli_args(parser):
         "--aml-auth",
         dest="aml_auth",
         type=str,
-        choices=["azurecli", "msi", "interactive"],
+        choices=["azurecli", "msi", "interactive", "aml_job"],
         default="interactive",
     )
     parser.add_argument(
@@ -146,7 +146,9 @@ def azureml_connect_cli(args):
     else:
         auth = None
 
-    if args.aml_config:
+    if args.aml_auth == "aml_job":
+        aml_ws = Run.get_context().experiment.workspace
+    elif args.aml_config:
         config_dir = os.path.dirname(args.aml_config)
         config_file_name = os.path.basename(args.aml_config)
 
