@@ -597,7 +597,7 @@ class AMLPipelineHelper:
         datastore_name=None,
         **custom_runtime_arguments,
     ):
-        """Applies settings for a Synapse component. Will use same configs as for HDI components.
+        """Applies settings for a Synapse component. Shrike will not set default runsettings except for spark_identity.
 
         Args:
             module_name (str): name of the module from the module manifest (required_modules() method)
@@ -629,42 +629,61 @@ class AMLPipelineHelper:
             log.info(f"Adding custom runtime arguments {custom_runtime_arguments}")
 
         new_conf = (
-            self.config.compute.hdi_conf if "hdi_conf" in self.config.compute else None
+            self.config.compute.synapse_conf
+            if "synapse_conf" in self.config.compute
+            else None
         )
         if conf is not None:
             new_conf = conf
         if new_conf is not None:
             if isinstance(new_conf, str):
                 new_conf = json.loads(new_conf)
-            elif isinstance(new_conf, DictConfig):
+            elif isinstance(new_conf, DictConfig) or isinstance(new_conf, dict):
                 new_conf = flatten(dict(new_conf), reducer="dot")
             else:
-                raise ValueError(
-                    "computed.hdi_conf is not a valid json string or a single tested configuration."
+                raise TypeError(
+                    f"compute.synapse_conf of type {type(new_conf)} is not a valid json string or a single tested configuration."
                 )
+            if self.module_loader.is_local(module_name):
+                new_conf = json.dumps(new_conf)
+            module_instance.runsettings.spark.configure(
+                conf=new_conf,
+            )
 
         module_instance.runsettings.configure(target=target)
+        module_instance.runsettings.spark_identity.configure(type="managed")
 
+        if "synapse_driver_memory" in self.config.compute:
+            driver_memory = driver_memory or self.config.compute.synapse_driver_memory
+        if driver_memory:
+            module_instance.runsettings.spark.configure(driver_memory=driver_memory)
+        if "synapse_driver_cores" in self.config.compute:
+            driver_cores = driver_cores or self.config.compute.synapse_driver_cores
+        if driver_cores:
+            module_instance.runsettings.spark.configure(driver_cores=driver_cores)
+        if "synapse_executor_memory" in self.config.compute:
+            executor_memory = (
+                executor_memory or self.config.compute.synapse_executor_memory
+            )
+        if executor_memory:
+            module_instance.runsettings.spark.configure(executor_memory=executor_memory)
+        if "synapse_number_executors" in self.config.compute:
+            number_executors = (
+                number_executors or self.config.compute.synapse_number_executors
+            )
+        if number_executors:
+            module_instance.runsettings.spark.configure(
+                number_executors=number_executors
+            )
+        if "synapse_executor_cores" in self.config.compute:
+            executor_cores = (
+                executor_cores or self.config.compute.synapse_executor_cores
+            )
+        if executor_cores:
+            module_instance.runsettings.spark.configure(executor_cores=executor_cores)
         module_instance.runsettings.spark.configure(
-            driver_memory=driver_memory
-            if driver_memory is not None
-            else self.config.compute.hdi_driver_memory,
-            driver_cores=driver_cores
-            if driver_cores is not None
-            else self.config.compute.hdi_driver_cores,
-            executor_memory=executor_memory
-            if executor_memory is not None
-            else self.config.compute.hdi_executor_memory,
-            executor_cores=executor_cores
-            if executor_cores is not None
-            else self.config.compute.hdi_executor_cores,
-            number_executors=number_executors
-            if number_executors is not None
-            else self.config.compute.hdi_number_executors,
-            conf=new_conf,
             **custom_runtime_arguments,
         )
-
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
         self._set_all_outputs_to(
@@ -1127,10 +1146,13 @@ class AMLPipelineHelper:
         )
 
         if "name" in module_manifest_entry:
-            if "source" in module_manifest_entry:
+            if ("source" in module_manifest_entry) and (module_manifest_entry.source):
+                # This indicates that user is using the deprecated 'source' config in their yaml file, since
+                # the default value of 'source' config has been override. Throw out warning and ask users to remove it.
                 log.warning(
                     "!!IMPORTANT: Key word `source` is deprecated for module artifacts. Please remove it."
                 )
+
             if module_manifest_entry["name"] == module_instance.name:
                 return
             if "namespace" in module_manifest_entry:
